from setuptools import setup

setup(name='mh_universal_functions',
      version='2020.6.28.2',
      description='General functions library',
      long_description='General functions library to be used with pir.py and rha.py',
      url='https://pypi.org/project/mh-universal-functions',
      author='MH',
      author_email='ibhmduu1721nhg11.11@o2mail.de',
      license='MIT',
      packages=['mh_universal_functions'],
      python_requires='>=3.7',
      zip_safe=False)
